==> seedsui-react-5.7.93.tgz: package/lib/Select/Modal/Head.bak/Cancel.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "caption", "disabled"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
var Cancel = function Cancel(_ref) {
  var cancelProps = _ref.cancelProps,
    onCancelClick = _ref.onCancelClick;
  // 确定和取消按钮
  var _ref2 = cancelProps || {},
    visible = _ref2.visible,
    cancelCaption = _ref2.caption,
    cancelDisabled = _ref2.disabled,
    otherCancelProps = _objectWithoutProperties(_ref2, _excluded);

  // 点击取消
  function handleCancelClick(e) {
    e.stopPropagation();
    if (cancelProps !== null && cancelProps !== void 0 && cancelProps.onClick) cancelProps.onClick(e);
    if (onCancelClick) onCancelClick(e);
  }
  return /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCancelProps), {}, {
    className: "".concat(cancelCaption ? 'picker-cancel' : 'picker-close').concat(otherCancelProps.className ? ' ' + otherCancelProps.className : '').concat(cancelDisabled === true ? ' disabled' : ''),
    onClick: handleCancelClick,
    children: cancelCaption || /*#__PURE__*/_jsx("div", {
      className: "picker-icon-close"
    })
  }));
};
export default Cancel;

==> seedsui-react-5.8.44.tgz: package/lib/Select/Modal/Head.bak/Cancel.js <==
var _excluded = ["visible", "caption", "disabled"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
var Cancel = function Cancel(_ref) {
  var cancelProps = _ref.cancelProps,
    onCancelClick = _ref.onCancelClick;
  // 确定和取消按钮
  var _ref2 = cancelProps || {},
    visible = _ref2.visible,
    cancelCaption = _ref2.caption,
    cancelDisabled = _ref2.disabled,
    otherCancelProps = _objectWithoutProperties(_ref2, _excluded);

  // 点击取消
  function handleCancelClick(e) {
    e.stopPropagation();
    if (cancelProps !== null && cancelProps !== void 0 && cancelProps.onClick) cancelProps.onClick(e);
    if (onCancelClick) onCancelClick(e);
  }
  return /*#__PURE__*/React.createElement("div", _extends({}, otherCancelProps, {
    className: "".concat(cancelCaption ? 'picker-cancel' : 'picker-close').concat(otherCancelProps.className ? ' ' + otherCancelProps.className : '').concat(cancelDisabled === true ? ' disabled' : ''),
    onClick: handleCancelClick
  }), cancelCaption || /*#__PURE__*/React.createElement("div", {
    className: "picker-icon-close"
  }));
};
export default Cancel;
